@@ -70,8 +70,7 @@ shiny::shinyUI(shiny::tagList(
         shiny::HTML(paste0(
           "Version:",
           "<br/>rBiasCorrection: ", utils::packageVersion("rBiasCorrection"),
-          "<br/>BiasCorrector: ", utils::packageVersion("BiasCorrector"),
-          "<br/><br/>\u00A9 Lorenz A. Kapsner<br/>"
+          "<br/>BiasCorrector: ", utils::packageVersion("BiasCorrector")
         ))
       )
     ),
